@@ -12,7 +12,7 @@ See version() below for version number.
 
 The MIT License (MIT)
 
-Copyright (c) 2021 Windell H. Oskay, Evil Mad Scientist Laboratories
+Copyright (c) 2022 Windell H. Oskay, Evil Mad Scientist Laboratories
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +38,7 @@ from . import ebb_serial
 
 def version():  # Report version number for this document
     ''' Return version number '''
-    return "0.21"  # Dated April 20, 2021
+    return "0.22"  # Dated 2022-02-22
 
 
 def doABMove(port_name, delta_a, delta_b, duration):
@@ -285,11 +285,11 @@ def sendEnableMotors(port_name, res):
     if port_name is not None:
         ebb_serial.command(port_name, 'EM,{0},{0}\r'.format(res))
 
-def QueryEnableMotors(port_name):
+def query_enable_motors(port_name):
     """
     Read current state of motors and their resolution.
     Returns: res_1, res_2
-        These are formatted the same way as the EM command
+        These are formatted the same way as the EM command:
 
         If res_x == 0, -> Motor disabled
         If res_x == 1, -> 16X microstepping
@@ -299,15 +299,14 @@ def QueryEnableMotors(port_name):
         If res_x == 5, -> No microstepping
 
     This query uses PI ( http://evil-mad.github.io/EggBot/ebb.html#PI )
-    to read the output state of the I/O pins that control the motor
-    driver ICs
+    to read the output state of the I/O pins that control the motor driver ICs
     """
     if port_name is not None:
         try:
             result = ebb_serial.query(port_name, 'PI,E,0\r') # Read motor 1 enable pin
-            enable_1 = result.split("PI,")[1].strip() == "1"
+            enable_1 = result.split("PI,")[1].strip() == "0"
             result = ebb_serial.query(port_name, 'PI,C,1\r') # Read motor 2 enable pin
-            enable_2 = result.split("PI,")[1].strip() == "1"
+            enable_2 = result.split("PI,")[1].strip() == "0"
             result = ebb_serial.query(port_name, 'PI,E,2\r') # Read MS1
             ms_1 = result.split("PI,")[1].strip() == "1"
             result = ebb_serial.query(port_name, 'PI,E,1\r') # Read MS2
